package com.xkrs.controller;

import com.xkrs.dao.DataSourceDao;
import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.qo.DataSourceQo;
import com.xkrs.service.DataSourceService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/19 17:05
 */
@RestController
public class DataSourceController {

    @Resource
    private DataSourceService dataSourceService;

    @Resource
    private DataSourceDao dataSourceDao;

    /**
     * 添加测量数据
     * @param dataSourceQo
     * @return
     */
    @PostMapping("/insertDataSource")
    public String insertDataSource(@RequestBody DataSourceQo dataSourceQo){
        return dataSourceService.insertDataSource(dataSourceQo);
    }

    /**
     * 查询某一产品的测量信息
     * @param dataModelNumber
     * @param dataBatchNumber
     * @param dataMachineCode
     * @param productNumber
     * @return
     */
    @GetMapping("/selectDataSource")
    public String selectDataSource(@RequestParam("dataModelNumber") String dataModelNumber,
                                   @RequestParam("dataBatchNumber") String dataBatchNumber,
                                   @RequestParam("dataMachineCode") String dataMachineCode,
                                   @RequestParam("productNumber") String productNumber){
        Locale locale = LocaleContextHolder.getLocale();
        List<Map<String, String>> maps = dataSourceDao.selectDataSource(dataModelNumber, dataBatchNumber, dataMachineCode, productNumber);
        if(maps == null || maps.size() == 0){
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE,"暂时没有该产品的测量信息！",locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,maps,locale);
    }

    /**
     * 查询全部的测量信息
     * @return
     */
    @GetMapping("/selectAllSource")
    public String selectAllSource(){
        Locale locale = LocaleContextHolder.getLocale();
        List<Map<String, String>> maps = dataSourceDao.selectAllSource();
        if(maps == null || maps.size() == 0){
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE,"暂时没有该产品的测量信息！",locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,maps,locale);
    }
}
